complete -c menyoki -n "__fish_use_subcommand" -s c -l config -d 'Set the configuration file'
complete -c menyoki -n "__fish_use_subcommand" -l color -d 'Set the main color'
complete -c menyoki -n "__fish_use_subcommand" -s v -l verbose -d 'Increase logging verbosity'
complete -c menyoki -n "__fish_use_subcommand" -s q -l quiet -d 'Do not show output'
complete -c menyoki -n "__fish_use_subcommand" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_use_subcommand" -s V -l version -d 'Print version information'
complete -c menyoki -n "__fish_use_subcommand" -f -a "record" -d 'Record an animation'
complete -c menyoki -n "__fish_use_subcommand" -f -a "split" -d 'Split an animation into frames'
complete -c menyoki -n "__fish_use_subcommand" -f -a "make" -d 'Make an animation from frames'
complete -c menyoki -n "__fish_use_subcommand" -f -a "capture" -d 'Capture an image'
complete -c menyoki -n "__fish_use_subcommand" -f -a "edit" -d 'Edit an image'
complete -c menyoki -n "__fish_use_subcommand" -f -a "analyze" -d 'Analyze an image'
complete -c menyoki -n "__fish_use_subcommand" -f -a "view" -d 'View an image'
complete -c menyoki -n "__fish_use_subcommand" -f -a "misc" -d 'Perform miscellaneous operations'
complete -c menyoki -n "__fish_use_subcommand" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from record" -l action-keys -d 'Set the action keys'
complete -c menyoki -n "__fish_seen_subcommand_from record" -l cancel-keys -d 'Set the cancel keys'
complete -c menyoki -n "__fish_seen_subcommand_from record" -s b -l border -d 'Set the border width'
complete -c menyoki -n "__fish_seen_subcommand_from record" -s p -l padding -d 'Set the record area padding'
complete -c menyoki -n "__fish_seen_subcommand_from record" -s s -l size -d 'Set the record area size'
complete -c menyoki -n "__fish_seen_subcommand_from record" -s d -l duration -d 'Set the duration for recording'
complete -c menyoki -n "__fish_seen_subcommand_from record" -s c -l countdown -d 'Set the countdown before recording'
complete -c menyoki -n "__fish_seen_subcommand_from record" -s t -l timeout -d 'Set the timeout for window selection'
complete -c menyoki -n "__fish_seen_subcommand_from record" -s i -l interval -d 'Set the refresh interval for window selection'
complete -c menyoki -n "__fish_seen_subcommand_from record" -l font -d 'Set the font to use for window selection'
complete -c menyoki -n "__fish_seen_subcommand_from record" -l monitor -d 'Set the monitor to record as root window'
complete -c menyoki -n "__fish_seen_subcommand_from record" -s r -l root -d 'Record the root window'
complete -c menyoki -n "__fish_seen_subcommand_from record" -s f -l focus -d 'Record the focused window'
complete -c menyoki -n "__fish_seen_subcommand_from record" -l select -d 'Select the window to record'
complete -c menyoki -n "__fish_seen_subcommand_from record" -l parent -d 'Record the parent of the window'
complete -c menyoki -n "__fish_seen_subcommand_from record" -l with-alpha -d 'Record with the alpha channel'
complete -c menyoki -n "__fish_seen_subcommand_from record" -l no-keys -d 'Disable the action keys while recording'
complete -c menyoki -n "__fish_seen_subcommand_from record" -s m -l mouse -d 'Select the window with mouse click'
complete -c menyoki -n "__fish_seen_subcommand_from record" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from record" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from record" -f -a "gif" -d 'Use the GIF encoder'
complete -c menyoki -n "__fish_seen_subcommand_from record" -f -a "apng" -d 'Use the APNG encoder'
complete -c menyoki -n "__fish_seen_subcommand_from record" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from record" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -s f -l fps -d 'Set the FPS'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -s q -l quality -d 'Set the frame quality (1-100)'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -s r -l repeat -d 'Set the number of repetitions'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -s s -l speed -d 'Set the animation speed'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -l cut-beginning -d 'Cut the beginning of the animation'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -l cut-end -d 'Cut the end of the animation'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -s d -l dir -d 'Set the directory to read frames'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -l format -d 'Set the animation format' -r -f -a "gif apng"
complete -c menyoki -n "__fish_seen_subcommand_from gif" -l gifski -d 'Use the gifski encoder'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -l fast -d 'Encode 3 times faster (gifski)'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -s n -l no-sort -d 'Use frames in the order given'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -s f -l fps -d 'Set the FPS'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -s q -l quality -d 'Set the frame quality (1-100)'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -s r -l repeat -d 'Set the number of repetitions'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -s s -l speed -d 'Set the animation speed'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -l cut-beginning -d 'Cut the beginning of the animation'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -l cut-end -d 'Cut the end of the animation'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -s d -l dir -d 'Set the directory to read frames'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -l format -d 'Set the animation format' -r -f -a "gif apng"
complete -c menyoki -n "__fish_seen_subcommand_from apng" -l gifski -d 'Use the gifski encoder'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -l fast -d 'Encode 3 times faster (gifski)'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -s n -l no-sort -d 'Use frames in the order given'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from split" -s d -l dir -d 'Set the output directory'
complete -c menyoki -n "__fish_seen_subcommand_from split" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from split" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from split" -f -a "png" -d 'Use the PNG encoder'
complete -c menyoki -n "__fish_seen_subcommand_from split" -f -a "jpg" -d 'Use the JPG encoder'
complete -c menyoki -n "__fish_seen_subcommand_from split" -f -a "webp" -d 'Use the WebP encoder'
complete -c menyoki -n "__fish_seen_subcommand_from split" -f -a "bmp" -d 'Use the BMP encoder'
complete -c menyoki -n "__fish_seen_subcommand_from split" -f -a "ico" -d 'Use the ICO encoder'
complete -c menyoki -n "__fish_seen_subcommand_from split" -f -a "tiff" -d 'Use the TIFF encoder'
complete -c menyoki -n "__fish_seen_subcommand_from split" -f -a "tga" -d 'Use the TGA encoder'
complete -c menyoki -n "__fish_seen_subcommand_from split" -f -a "pnm" -d 'Use the PNM encoder'
complete -c menyoki -n "__fish_seen_subcommand_from split" -f -a "ff" -d 'Use the farbfeld encoder'
complete -c menyoki -n "__fish_seen_subcommand_from split" -f -a "exr" -d 'Use the OpenEXR encoder'
complete -c menyoki -n "__fish_seen_subcommand_from split" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from split" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from png" -s c -l compression -d 'Set the compression level' -r -f -a "default fast best"
complete -c menyoki -n "__fish_seen_subcommand_from png" -s f -l filter -d 'Set the filter algorithm' -r -f -a "none sub up avg paeth"
complete -c menyoki -n "__fish_seen_subcommand_from png" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from png" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from png" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from png" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from jpg" -s q -l quality -d 'Set the image quality (1-100)'
complete -c menyoki -n "__fish_seen_subcommand_from jpg" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from jpg" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from jpg" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from jpg" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from webp" -s q -l quality -d 'Set the lossy encoding quality (1-100)'
complete -c menyoki -n "__fish_seen_subcommand_from webp" -s l -l lossless -d 'Use lossless encoding'
complete -c menyoki -n "__fish_seen_subcommand_from webp" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from webp" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from webp" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from webp" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from bmp" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from bmp" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from bmp" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from bmp" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from ico" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from ico" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from ico" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from ico" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from tiff" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from tiff" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from tiff" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from tiff" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from tga" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from tga" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from tga" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from tga" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from pnm" -s f -l format -d 'Set the PNM format' -r -f -a "bitmap graymap pixmap arbitrary"
complete -c menyoki -n "__fish_seen_subcommand_from pnm" -s e -l encoding -d 'Set the encoding for storing the samples' -r -f -a "binary ascii"
complete -c menyoki -n "__fish_seen_subcommand_from pnm" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from pnm" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from pnm" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from pnm" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from ff" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from ff" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from ff" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from ff" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from exr" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from exr" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from exr" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from exr" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from make" -s f -l fps -d 'Set the FPS'
complete -c menyoki -n "__fish_seen_subcommand_from make" -s q -l quality -d 'Set the frame quality (1-100)'
complete -c menyoki -n "__fish_seen_subcommand_from make" -s r -l repeat -d 'Set the number of repetitions'
complete -c menyoki -n "__fish_seen_subcommand_from make" -s s -l speed -d 'Set the animation speed'
complete -c menyoki -n "__fish_seen_subcommand_from make" -l cut-beginning -d 'Cut the beginning of the animation'
complete -c menyoki -n "__fish_seen_subcommand_from make" -l cut-end -d 'Cut the end of the animation'
complete -c menyoki -n "__fish_seen_subcommand_from make" -s d -l dir -d 'Set the directory to read frames'
complete -c menyoki -n "__fish_seen_subcommand_from make" -l format -d 'Set the animation format' -r -f -a "gif apng"
complete -c menyoki -n "__fish_seen_subcommand_from make" -l gifski -d 'Use the gifski encoder'
complete -c menyoki -n "__fish_seen_subcommand_from make" -l fast -d 'Encode 3 times faster (gifski)'
complete -c menyoki -n "__fish_seen_subcommand_from make" -s n -l no-sort -d 'Use frames in the order given'
complete -c menyoki -n "__fish_seen_subcommand_from make" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from make" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from make" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from make" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -l action-keys -d 'Set the action keys'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -l cancel-keys -d 'Set the cancel keys'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -s b -l border -d 'Set the border width'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -s p -l padding -d 'Set the capture area padding'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -s s -l size -d 'Set the capture area size'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -s d -l duration -d 'Set the duration for recording'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -s c -l countdown -d 'Set the countdown before capturing'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -s t -l timeout -d 'Set the timeout for window selection'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -s i -l interval -d 'Set the refresh interval for window selection'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -l font -d 'Set the font to use for window selection'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -l monitor -d 'Set the monitor to capture as root window'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -s r -l root -d 'Capture the root window'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -s f -l focus -d 'Capture the focused window'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -l select -d 'Select the window to capture'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -l parent -d 'Capture the parent of the window'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -l with-alpha -d 'Capture with the alpha channel'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -l no-keys -d 'Disable the action keys while recording'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -s m -l mouse -d 'Select the window with mouse click'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -f -a "png" -d 'Use the PNG encoder'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -f -a "jpg" -d 'Use the JPG encoder'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -f -a "webp" -d 'Use the WebP encoder'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -f -a "bmp" -d 'Use the BMP encoder'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -f -a "ico" -d 'Use the ICO encoder'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -f -a "tiff" -d 'Use the TIFF encoder'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -f -a "tga" -d 'Use the TGA encoder'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -f -a "pnm" -d 'Use the PNM encoder'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -f -a "ff" -d 'Use the farbfeld encoder'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -f -a "exr" -d 'Use the OpenEXR encoder'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from capture" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from png" -s c -l compression -d 'Set the compression level' -r -f -a "default fast best"
complete -c menyoki -n "__fish_seen_subcommand_from png" -s f -l filter -d 'Set the filter algorithm' -r -f -a "none sub up avg paeth"
complete -c menyoki -n "__fish_seen_subcommand_from png" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from png" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from png" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from png" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from jpg" -s q -l quality -d 'Set the image quality (1-100)'
complete -c menyoki -n "__fish_seen_subcommand_from jpg" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from jpg" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from jpg" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from jpg" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from webp" -s q -l quality -d 'Set the lossy encoding quality (1-100)'
complete -c menyoki -n "__fish_seen_subcommand_from webp" -s l -l lossless -d 'Use lossless encoding'
complete -c menyoki -n "__fish_seen_subcommand_from webp" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from webp" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from webp" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from webp" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from bmp" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from bmp" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from bmp" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from bmp" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from ico" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from ico" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from ico" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from ico" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from tiff" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from tiff" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from tiff" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from tiff" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from tga" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from tga" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from tga" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from tga" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from pnm" -s f -l format -d 'Set the PNM format' -r -f -a "bitmap graymap pixmap arbitrary"
complete -c menyoki -n "__fish_seen_subcommand_from pnm" -s e -l encoding -d 'Set the encoding for storing the samples' -r -f -a "binary ascii"
complete -c menyoki -n "__fish_seen_subcommand_from pnm" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from pnm" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from pnm" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from pnm" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from ff" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from ff" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from ff" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from ff" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from exr" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from exr" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from exr" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from exr" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -l crop -d 'Apply padding to crop the image'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -l resize -d 'Resize the image without keeping the aspect ratio'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -l ratio -d 'Resize the image proportionally by aspect ratio'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -l rotate -d 'Rotate the image (clockwise)' -r -f -a "90 180 270"
complete -c menyoki -n "__fish_seen_subcommand_from edit" -l flip -d 'Flip the image' -r -f -a "horizontal vertical"
complete -c menyoki -n "__fish_seen_subcommand_from edit" -l blur -d 'Blur the image'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -l hue -d 'Adjust the hue of the image'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -l contrast -d 'Adjust the contrast of the image'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -l brightness -d 'Adjust the brightness of the image'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -l filter -d 'Set the sampling filter for scaling' -r -f -a "nearest triangle catmull-rom gaussian lanczos3"
complete -c menyoki -n "__fish_seen_subcommand_from edit" -l convert -d 'Convert image using the given encoder'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -l grayscale -d 'Convert image to grayscale'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -l invert -d 'Invert the colors of the image'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -f -a "gif" -d 'Use the GIF encoder'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -f -a "apng" -d 'Use the APNG encoder'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -f -a "png" -d 'Use the PNG encoder'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -f -a "jpg" -d 'Use the JPG encoder'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -f -a "webp" -d 'Use the WebP encoder'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -f -a "bmp" -d 'Use the BMP encoder'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -f -a "ico" -d 'Use the ICO encoder'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -f -a "tiff" -d 'Use the TIFF encoder'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -f -a "tga" -d 'Use the TGA encoder'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -f -a "pnm" -d 'Use the PNM encoder'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -f -a "ff" -d 'Use the farbfeld encoder'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -f -a "exr" -d 'Use the OpenEXR encoder'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from edit" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -s f -l fps -d 'Set the FPS'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -s q -l quality -d 'Set the frame quality (1-100)'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -s r -l repeat -d 'Set the number of repetitions'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -s s -l speed -d 'Set the animation speed'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -l cut-beginning -d 'Cut the beginning of the animation'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -l cut-end -d 'Cut the end of the animation'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -s d -l dir -d 'Set the directory to read frames'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -l format -d 'Set the animation format' -r -f -a "gif apng"
complete -c menyoki -n "__fish_seen_subcommand_from gif" -l gifski -d 'Use the gifski encoder'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -l fast -d 'Encode 3 times faster (gifski)'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -s n -l no-sort -d 'Use frames in the order given'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from gif" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -s f -l fps -d 'Set the FPS'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -s q -l quality -d 'Set the frame quality (1-100)'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -s r -l repeat -d 'Set the number of repetitions'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -s s -l speed -d 'Set the animation speed'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -l cut-beginning -d 'Cut the beginning of the animation'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -l cut-end -d 'Cut the end of the animation'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -s d -l dir -d 'Set the directory to read frames'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -l format -d 'Set the animation format' -r -f -a "gif apng"
complete -c menyoki -n "__fish_seen_subcommand_from apng" -l gifski -d 'Use the gifski encoder'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -l fast -d 'Encode 3 times faster (gifski)'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -s n -l no-sort -d 'Use frames in the order given'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from apng" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from png" -s c -l compression -d 'Set the compression level' -r -f -a "default fast best"
complete -c menyoki -n "__fish_seen_subcommand_from png" -s f -l filter -d 'Set the filter algorithm' -r -f -a "none sub up avg paeth"
complete -c menyoki -n "__fish_seen_subcommand_from png" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from png" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from png" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from png" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from jpg" -s q -l quality -d 'Set the image quality (1-100)'
complete -c menyoki -n "__fish_seen_subcommand_from jpg" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from jpg" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from jpg" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from jpg" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from webp" -s q -l quality -d 'Set the lossy encoding quality (1-100)'
complete -c menyoki -n "__fish_seen_subcommand_from webp" -s l -l lossless -d 'Use lossless encoding'
complete -c menyoki -n "__fish_seen_subcommand_from webp" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from webp" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from webp" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from webp" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from bmp" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from bmp" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from bmp" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from bmp" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from ico" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from ico" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from ico" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from ico" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from tiff" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from tiff" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from tiff" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from tiff" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from tga" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from tga" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from tga" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from tga" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from pnm" -s f -l format -d 'Set the PNM format' -r -f -a "bitmap graymap pixmap arbitrary"
complete -c menyoki -n "__fish_seen_subcommand_from pnm" -s e -l encoding -d 'Set the encoding for storing the samples' -r -f -a "binary ascii"
complete -c menyoki -n "__fish_seen_subcommand_from pnm" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from pnm" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from pnm" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from pnm" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from ff" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from ff" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from ff" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from ff" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from exr" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from exr" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from exr" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from exr" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from analyze" -s t -l time-zone -d 'Set the time zone of the report' -r -f -a "utc local"
complete -c menyoki -n "__fish_seen_subcommand_from analyze" -l timestamp -d 'Use Unix timestamp for report dates'
complete -c menyoki -n "__fish_seen_subcommand_from analyze" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from analyze" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from analyze" -f -a "save" -d 'Save the output file(s)'
complete -c menyoki -n "__fish_seen_subcommand_from analyze" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s d -l date -d 'Add formatted date/time to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s e -l with-extension -d 'Always save the file with an extension'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s t -l timestamp -d 'Add Unix timestamp to the file name'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from save" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from view" -s t -l transparent -d 'Display transparent image with transparent background'
complete -c menyoki -n "__fish_seen_subcommand_from view" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from view" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from misc" -s g -l gen-completions -d 'Generate completions for the specified shell' -r -f -a "bash fish zsh powershell elvish"
complete -c menyoki -n "__fish_seen_subcommand_from misc" -s h -l help -d 'Print help information'
complete -c menyoki -n "__fish_seen_subcommand_from misc" -s V -l version -d 'Prints version information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c menyoki -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
